@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__author__ = """Christoph Schabert"""
-__email__ = 'christoph@schabert.me'
-__version__ = '0.1.11'
+__author__ = """CloudHeads"""
+__email__ = 'theguys@cloudheads.io'
+__version__ = '0.1.12'
 
 
 class Event(object):
